/*********************************************************************
 *
 *      Copyright (C) 1999-2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      JSwat Actions
 * FILE:        VMSuspendAction.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      04/10/99        Initial version
 *
 * $Id: VMSuspendAction.java 699 2002-11-30 08:27:59Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.action;

import com.bluemarsh.jswat.Log;
import com.bluemarsh.jswat.Session;
import com.sun.jdi.VirtualMachine;
import java.awt.event.ActionEvent;

/**
 * Implements the Virtual Machine suspend action. It doens't do
 * much except contact the running VM and suspend it.
 *
 * @author  Nathan Fiedler
 */
public class VMSuspendAction extends JSwatAction implements SessionAction {

    /**
     * Creates a new VMSuspendAction object with the default action
     * command string of "vmSuspend".
     */
    public VMSuspendAction() {
        super("vmSuspend");
    } // VMSuspendAction

    /**
     * Performs the virtual machine suspend action. Finds the
     * appropriate VM and suspends it.
     *
     * @param  event  action event
     */
    public void actionPerformed(ActionEvent event) {
        // ask the user for the class name
        Session session = getSession(event);
        try {
            session.suspendVM(this);
        } catch (IllegalStateException ise) {
            // ignore it
        }
    } // actionPerformed

    /**
     * Returns true to indicate that this action should be disabled
     * when the debuggee is resumed.
     *
     * @return  true to disable, false to leave as-is.
     */
    public boolean disableOnResume() {
        return false;
    } // disableOnResume

    /**
     * Returns true to indicate that this action should be disabled
     * when the debuggee is suspended.
     *
     * @return  true to disable, false to leave as-is.
     */
    public boolean disableOnSuspend() {
        return true;
    } // disableOnSuspend

    /**
     * Returns true to indicate that this action should be disabled
     * while the session is active, and enabled when the session
     * is not active. This is the opposite of how SessionActions
     * normally behave.
     *
     * @return  true to disable when active, false to enable.
     */
    public boolean disableWhenActive() {
        return false;
    } // disableWhenActive
} // VMSuspendAction
